OverrideErrorResponse class abstract

body, headers, and statusCode are optional, if any of them are set, they will be used to override the response body, headers, or statusCode.

Constructors

OverrideErrorResponse()
const

Properties

body Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited