PayloadImpl class

Implemented types

Constructors

PayloadImpl(Object? body, {required Encoding encoding})
factory
PayloadImpl.encoded(dynamic body, {required Encoding encoding})
factory

Properties

contentLength int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
override
coerce(Headers headers) Future<BodyData?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Stream<List<int>>
override
readAsString({Encoding encoding = utf8}) String
override
resolve(Headers headers) Future<Body>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

additionalParsers Map<String, BodyParser>
getter/setter pair