WebSocketRequestImpl class

Inheritance
Implemented types

Constructors

WebSocketRequestImpl.fromRequest(FullRequest request, Future<void> close(int code, String reason))

Properties

body → Body
The body of the request, resolved from the original payload.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
headers Headers
finalinherited
method String
no setterinherited
originalPayload Payload
no setterinherited
pathParameters Map<String, String>
The path parameters of the request.
getter/setter pairinherited
payload → Body
no setterinherited
payloadResolver PayloadResolver?
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
queryParameters Map<String, dynamic>
no setterinherited
queryParametersAll Map<String, List>
no setterinherited
request UnderlyingRequest
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<String>
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uri Uri
no setterinherited

Methods

addCleanUp(void cleanUp()) → void
inherited
close([int code = 1000, String reason = 'Closed by the server']) Future<void>
Cleans up any resources used by the request
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideBody(Object? data) Future<void>
override
resolvePayload() Future<void>
override
toString() String
A string representation of this object.
inherited
upgradeToWebSocket({Duration? ping}) Future<WebSocket>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited