revali_router library
Classes
- AddData
- AllowOrigins
- App
- AppConfig
- Args
-
AsyncWebSocketSender<
T> -
AsyncWebSocketSenderImpl<
T> -
BaseBodyData<
T> - BaseRoute
- BinaryBodyData
-
Bind<
T> - A custom parameter that can be used in routes.
- BindContext
- BindContextImpl
- Binds
- Body
- BodyData
- BodyImpl
- BodyParser
- ByteStreamBodyData
- CannedResponse
- Catches
- Defines a list of catchers that will be used to catch exceptions thrown by the route handler.
- CleanUp
- CleanUpImpl
- CloseWebSocket
- CloseWebSocketImpl
- CombineComponents
- CombineComponentsApplier
- Combines
- CommonHeadersMixin
- Context
- ContextImpl
- Controller
- Cookie
- Cookies
- CookiesImpl
- Data
- DataImpl
- DefaultExceptionCatcher
- DefaultResponseHandler
- DefaultResponses
- Delete
- Dep
- Used to mark a parameter as a type that should be resolved by the dependency injection system.
- DI
- DIHandler
- EmptyHeaders
-
ExceptionCatcher<
T> -
ExceptionCatcherResult<
T> - Execute
- ExpectHeaders
- FileBodyData
- Find
- FormDataBodyData
- FullRequest
- Get
- Guard
- GuardResult
- Guards
- HandleWebSocket
- Head
- Header
- Headers
- HeadersImpl
- Helper
- Inject
- A marker class for injectable arguments
- Interceptor
- Intercepts
- JsonBodyData
-
JsonData<
T> - LifecycleComponent
- A marker interface for a lifecycle component.
- LifecycleComponents
- LifecycleComponentsImpl
- ListBodyData
- MemoryFile
- MemoryFileBodyData
- Meta
- MetaData
- A marker interface for all meta annotations.
- MetaScope
- MetaScopeImpl
- Method
- Middleware
- MiddlewareResult
- Middlewares
- defines the middleware to be used for the controller/route
- NullBodyData
- Observer
- Observers
- Defines a list of observers that will be used to observe the requests and responses of the server.
- OverrideErrorResponse
- body, headers, and statusCode are optional, if any of them are set, they will be used to override the response body, headers, or statusCode.
- Param
- Patch
- Payload
- PayloadImpl
-
Pipe<
T, R> - PipeContext
- PipeContextImpl
- Post
- PreventHeaders
-
PrimitiveNonStringBodyData<
T> - Put
- Query
- Redirect
- Reflect
- ReflectData
- Reflector
- Request
- RequestContext
- RequestContextImpl
- RequestCookies
- RequestHeaders
- RequestImpl
- Response
- ResponseCookies
- ResponseHandler
- ResponseHeaders
- ResponseImpl
- Route
- RouteEntry
- RouteMatch
- Router
- Run
- RunCatchers
- RunGuards
- RunInterceptors
- RunMiddlewares
- RunOptions
- RunOriginCheck
- RunRedirect
-
SequentialExecutor<
T> - SetCookieHeaders
- SetCookies
- SetCookiesImpl
- SetHeader
- SimpleResponse
- SSE
- SseResponseHandler
- SseRoute
- StatusCode
-
StreamBodyData<
T> - StringBodyData
- StringContent
- UnderlyingRequest
- UnderlyingRequestImpl
- WebSocket
- WebSocketContext
- WebSocketContextImpl
- WebSocketHandler
- WebSocketRequest
- WebSocketRequestImpl
- WebSocketResponse
- WebsocketResponseHandler
- WebSocketRoute
Extensions
Constants
- kDebugMode → const bool
- kProfileMode → const bool
- kReleaseMode → const bool
Functions
-
bodyForError(
Body? body, {required Object error, required StackTrace stackTrace}) → BodyData? -
coerce(
String value) → dynamic -
handleRequests(
HttpServer server, Future< Response> handler(RequestContext context), Future<ResponseHandler> responseHandler(RequestContext context), void close()) → Future<void>
Typedefs
-
Binary
= List<
int> - DebugErrorResponse = Response Function(Response response, {required Object error, required StackTrace stackTrace})
-
InterceptorPostResult
= FutureOr<
void> -
InterceptorPreResult
= FutureOr<
void> - PayloadBody = Body
-
PayloadResolver
= Future<
Body> Function() -
PayloadTransformer
= StreamTransformer<
List< int> , List<int> > - WebSocketCallBack = Stream Function(WebSocketContext)