OverrideErrorResponse class abstract
body, headers, and statusCode are optional, if any of them are set, they will be used to override the response body, headers, or statusCode.
Constructors
- OverrideErrorResponse()
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited